from django.conf import settings
from django.test import TestCase, override_settings

from dseagull.checks import jwt_check


class TestChecks(TestCase):

    @override_settings(JWT_KEY=None, JWT_EXP=None)
    def test_pagination_settings(self):
        self.assertIsNone(settings.JWT_KEY)
        self.assertIsNone(settings.JWT_EXP)

        errors = jwt_check(app_configs=None)
        error_msg = ';'.join([error.msg for error in errors])
        self.assertIn('请配置 jwt 的加密秘钥 JWT_KEY', error_msg)
        self.assertIn('请配置 jwt 的过期时间(单位秒) JWT_EXP', error_msg)



from uuid import uuid4

from django.conf import settings
from django.utils import timezone
from django.utils.deprecation import MiddlewareMixin

# from naval_system.drf.logging import LOCAL


class BaseMiddleware(MiddlewareMixin): # todo

    @classmethod
    def process_request(cls, request):

        LOCAL.remote_ip = request.META.get('HTTP_X_FORWARDED_FOR') or \
                          request.META.get('HTTP_X_REAL_IP') or \
                          request.META.get('REMOTE_ADDR') or ''
        request.request_id = LOCAL.request_id = request.META.get('HTTP_X_REQUEST_ID', str(uuid4()))
        request.start_at = timezone.localtime()

        try:
            body = request.body.decode('utf8')
            body = body[:1000]
            settings.LOGGER.info(f'[request] method:{request.method};path={request.path}', )
            settings.LOGGER.info(f"[request] body:{body}", )
        except:  # noqa
            pass

    def process_response(self, request, response):  # noqa
        try:
            response_content = response.content
        except:  # noqa
            return response
        if len(response_content) > 1000:
            response_content = response_content[:997] + b'...'
        try:
            response_content = response_content.decode('utf8')
        except:  # noqa
            pass

        duration = timezone.localtime() - request.start_at
        settings.LOGGER.info(f'[process_response] status_code:{response.status_code};duration:{duration.seconds}.{duration.microseconds:0>6};content:{response_content}')
        if duration.seconds >= 10:
            settings.LOGGER.info(f'[请求超时] method:{request.method};path={request.path};duration:{duration.seconds}.{duration.microseconds:0>6};{request.request_id=}', )
        return response



import uuid

from django.conf import settings
from django.core.checks import Tags, register, Critical


@register(Tags.compatibility)
def jwt_check(app_configs, **kwargs) -> list:  # noqa
    errors = []
    if not hasattr(settings, 'JWT_KEY') or not settings.JWT_KEY:
        errors.append(
            Critical(
                f"请配置 jwt 的加密秘钥 JWT_KEY, 比如: JWT_KEY = '{uuid.uuid4().hex}{uuid.uuid4().hex}'"
            )
        )

    if not hasattr(settings, 'JWT_EXP') or not settings.JWT_EXP:
        errors.append(
            Critical(
                "请配置 jwt 的过期时间(单位秒) JWT_EXP, 比如: JWT_EXP = 60 * 60 * 24 * 30"
            )
        )
    return errors
